<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddMeta</name>
    <message>
        <source>Insert a:</source>
        <translation>Set inn:</translation>
    </message>
    <message>
        <source>&amp;Marker</source>
        <translation>ein &amp;markør</translation>
    </message>
    <message>
        <source>Voice &amp;Track</source>
        <translation>eit røys&amp;t-spor</translation>
    </message>
    <message>
        <source>Log C&amp;hain</source>
        <translation>Ei logg&amp;kjede</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>EditChain</name>
    <message>
        <source>Edit Log Chain</source>
        <translation>Rediger loggkjede</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Start på:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Start med ein gong</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Gjer til neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Krysston</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Overgangstype:</translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation>Loggnamn</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vel</translation>
    </message>
    <message>
        <source>Log Description</source>
        <translation>Loggskildring</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Overgang viss førre korg endar før</translation>
    </message>
</context>
<context>
    <name>EditLog</name>
    <message>
        <source>Edit Log</source>
        <translation>Rediger logg</translation>
    </message>
    <message>
        <source>Log Name:</source>
        <translation>Loggnamn:</translation>
    </message>
    <message>
        <source>Tracks:</source>
        <translation>Spor:</translation>
    </message>
    <message>
        <source>Origin:</source>
        <translation>Opphav:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Tenest:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Enable AutoRefresh:</source>
        <translation>Skru på AutoOppdater:</translation>
    </message>
    <message>
        <source>Start Date:</source>
        <translation>Startdato:</translation>
    </message>
    <message>
        <source>End Date:</source>
        <translation>Sluttdato:</translation>
    </message>
    <message>
        <source>Start Date Enabled</source>
        <translation>Startdato på</translation>
    </message>
    <message>
        <source>End Date Enabled</source>
        <translation>Sluttdato på</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">TID</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">OVERG</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">KORG</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTIST</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">KLIENT</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENT</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">SELSKAP</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="obsolete">KJELDE</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="obsolete">LINE-ID</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">TELLING</translation>
    </message>
    <message>
        <source>Insert
Cart</source>
        <translation>Set inn
korg</translation>
    </message>
    <message>
        <source>Insert
Meta</source>
        <translation>Set inn
meta</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klypp ut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lagra</translation>
    </message>
    <message>
        <source>Save
&amp;As</source>
        <translation type="obsolete">Lagra &amp;som</translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation>Ra&amp;pportar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Invalid Carts</source>
        <translation>Ugyldige korger</translation>
    </message>
    <message>
        <source>This log contains one or more carts
that are invalid for the selected service!</source>
        <translation>Denne loggen inneheld ei eller fleire
korger som er ugyldige for denne tenesta!</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation>Røyst-spor</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!

Do you still want to save?</source>
        <translation>Loggen inneheld korger som er skrudd av
for denne tenesta!

Vil du lagra likevel?</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Legg til logg</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">Loggen eksisterer</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">Loggen finst frå før!</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>The log has been modified.
Do you want to save your changes?</source>
        <translation>Loggen er endra.
Vil du lagra endringane?</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!</source>
        <translation>Loggen inneheld korger som er
skrudd av for denne tenesta!</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SPEL</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOPP</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>KRYSSTON</translation>
    </message>
    <message>
        <source>OVERLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation>[fann ikkje korga]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKØR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation>LOGGKJEDE</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikkimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[trafikkimport]</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation>Trafikk</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musikk</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Voice Tracker</source>
        <translation>Spor røyst</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- slutt på loggen ---</translation>
    </message>
    <message>
        <source>[INVALID CART]</source>
        <translation>[UGYLDIG KORG]</translation>
    </message>
    <message>
        <source>Delete on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished">Vel</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save log, audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="obsolete">Brukar</translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished">Korg</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Tittel</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artist</translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Selskap</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ext Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Start Times As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sch. Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Est. Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditLogLine</name>
    <message>
        <source>Edit Log Entry</source>
        <translation>Rediger loggoppføring</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Start på:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Start med ein gong</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Gjer til neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Krysston</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Overgangstype:</translation>
    </message>
    <message>
        <source>No Fade When Segueing At End</source>
        <translation type="obsolete">Inga uttoning når du overtonar ved slutten</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Korg</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <source>Select
Cart</source>
        <translation>Vel korg</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Overgang viss førre korg endar før</translation>
    </message>
    <message>
        <source>Missing Cart</source>
        <translation>Manglar korg</translation>
    </message>
    <message>
        <source>You must supply a cart number!</source>
        <translation>Du må skriva inn eit korgnummer!</translation>
    </message>
    <message>
        <source>Disabled Cart</source>
        <translation>Korga er skrudd av</translation>
    </message>
    <message>
        <source>This cart belongs to a disabled
group for the specified service!</source>
        <translation>Denne korga høyrer til ei gruppe
som er skrudd av for denne tenesta!</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMarker</name>
    <message>
        <source>Edit Log Marker</source>
        <translation>Rediger loggmarkør</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Start på:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Start med ein gong</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Gjer til neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Krysston</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Selskap</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Overgang viss førre korg endar før</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Overgangstype:</translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Rediger røystspormarkør</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Start på:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Start med ein gong</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Gjer til neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Krysston</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Overgang viss førre korg endar før</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Overgangstype:</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="obsolete">Vel ein logg</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NAMN</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">SKILDRING</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">TENEST</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="obsolete">RDLibrary-rapportar</translation>
    </message>
    <message>
        <source>Log Listing</source>
        <translation>Loggopplisting</translation>
    </message>
    <message>
        <source>Log Exception Report</source>
        <translation>Rapport for loggunntak</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>La&amp;g</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ingen]</translation>
    </message>
    <message>
        <source>Log Check</source>
        <translation>Loggsjekk</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>Fann ingen unntak.</translation>
    </message>
    <message>
        <source>Effective Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reports</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogEdit - Host</source>
        <translation type="obsolete">RdLogEdit - Vert</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="obsolete">Brukar: [Ukjent]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>LOG NAME</source>
        <translation type="obsolete">LOGGNAMN</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">SKILDRING</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">TENEST</translation>
    </message>
    <message>
        <source>MUSIC</source>
        <translation type="obsolete">MUSIKK</translation>
    </message>
    <message>
        <source>TRAFFIC</source>
        <translation type="obsolete">TRAFIKK</translation>
    </message>
    <message>
        <source>TRACKS</source>
        <translation type="obsolete">SPOR</translation>
    </message>
    <message>
        <source>VALID FROM</source>
        <translation type="obsolete">GYLDIG FRÅ</translation>
    </message>
    <message>
        <source>VALID TO</source>
        <translation type="obsolete">GYLDIG TIL</translation>
    </message>
    <message>
        <source>AUTO REFRESH</source>
        <translation type="obsolete">AUTO-OPPDATER</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">OPPHAV</translation>
    </message>
    <message>
        <source>LAST LINKED</source>
        <translation type="obsolete">SIST LENKA</translation>
    </message>
    <message>
        <source>LAST MODIFIED</source>
        <translation type="obsolete">SIST ENDRA</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Legg til</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Voice
&amp;Tracker</source>
        <translation>Røys&amp;t-
sporar</translation>
    </message>
    <message>
        <source>Log
Report</source>
        <translation>Logg-
rapport</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Brukar</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Legg til logg</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">Loggen eksisterer</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">Loggen finst frå før!</translation>
    </message>
    <message>
        <source>Delete Log</source>
        <translation>Slett logg</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Dette slettar òg</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="obsolete">røystspor som er kopla til denne loggen.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Sporet eksisterer</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Alltid</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="obsolete">RDLogEdit</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete these</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>logs?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with these logs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation type="unfinished">Loggnamn</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished">Musikk</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished">Trafikk</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Linked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenderDialog</name>
    <message>
        <source>Render Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering Log...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished">Vel</translation>
    </message>
    <message>
        <source>Audio Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[now]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As Specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Selected Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Treat as PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At STOP transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VoiceTracker</name>
    <message>
        <source>Voice Tracker</source>
        <translation type="unfinished">Spor røyst</translation>
    </message>
    <message>
        <source>Edit Cue Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo Segue Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Start Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set End Point Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set to Hook Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">TID</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">OVERG</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">KORG</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTIST</translation>
    </message>
    <message>
        <source>Do Over</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hit Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Lukk</translation>
    </message>
    <message>
        <source>No VoiceTrack Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No voicetracking group has been defined for this service,
therefore only existing transitions will be editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Creation Failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create new cart for voice track!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished">RDLogEdit</translation>
    </message>
    <message>
        <source>Audio Deletion Error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished">SPOR</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation type="unfinished">Røyst-spor</translation>
    </message>
    <message>
        <source>Track List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No more tracks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[end of log]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished">[fann ikkje korga]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished">MARKØR</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished">LOGGKJEDE</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished">LENKJE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished">[musikkimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished">[trafikkimport]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">SPEL</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">KRYSSTON</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOPP</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save segue changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit - Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">SELSKAP</translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished">Korg</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Tittel</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artist</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Selskap</translation>
    </message>
</context>
</TS>
